@@ -14,7 +14,8 @@
 
 import click
 
-from roe.utilities import utils as roe_utils
+from roe.utilities.init_utils import begin
+from roe.utilities.running_utils import list_packages, begin_packages
 
 
 @click.command()
@@ -28,8 +29,8 @@ def cli(local, file):
     2) Lists all packages that have been deployed
     3) Begins all packages that have been deployed
     """
-    roe_utils.begin(local, file)
-    roe_utils.list_packages(local)
-    roe_utils.begin_packages(local)
+    begin(local, file)
+    list_packages(local)
+    begin_packages(local)
 
     return
