@@ -14,7 +14,7 @@
 
 import click
 
-from roe.utilities import utils as roe_utils
+from roe.utilities.running_utils import end
 
 
 @click.command()
@@ -27,5 +27,5 @@ def cli(local):
     2) Stops all deployed packages
     3) Stops ROE-API container in Docker
     """
-    roe_utils.end(local)
+    end(local)
     return
