@@ -14,12 +14,12 @@
 
 import click
 
-from roe.utilities import utils as roe_utils
+from roe.utilities.running_utils import list_packages
 
 
 @click.command()
 @click.option("-l", "--local", is_flag=True, type=bool, help="List packages deployed locally.")
 def cli(local):
     """Lists deployed package details."""
-    roe_utils.list_packages(local)
+    list_packages(local)
     return
