@@ -14,7 +14,7 @@
 
 import click
 
-from roe.utilities import utils as roe_utils
+from roe.utilities.running_utils import logs
 
 
 @click.command()
@@ -23,5 +23,5 @@ from roe.utilities import utils as roe_utils
 @click.argument('package_name')
 def cli(local, package_name, tail):
     """Get package logs."""
-    roe_utils.logs(local, package_name, tail)
+    logs(local, package_name, tail)
     return
