@@ -14,7 +14,7 @@
 
 import click
 
-from roe.utilities import utils as roe_utils
+from roe.utilities.running_utils import verify
 
 
 @click.command()
@@ -22,5 +22,5 @@ from roe.utilities import utils as roe_utils
 @click.argument('folder_path')
 def cli(local, folder_path):
     """Deploy and start a package."""
-    roe_utils.verify(local, folder_path)
+    verify(local, folder_path)
     return
