@@ -20,7 +20,7 @@ def test_start_bad_package():
     """
     runner = CliRunner()
     # Deploys sample package to ensure something is running
-    runner.invoke(cmd_deploy.cli, ['-l', "-q", r'samples/myProject'])
+    runner.invoke(cmd_deploy.cli, ['-l', "-q", r'samples/simple_test'])
     result = runner.invoke(cli, ["-l", "-p", "roe-api"])
     assert isinstance(result.exception, errors.PackageExistenceError)
 
@@ -38,6 +38,6 @@ def test_start_no_running_packages():
 
 def test_start_package():
     runner = CliRunner()
-    runner.invoke(cmd_deploy.cli, ['-l', "-q", r'samples/myProject'])
-    result = runner.invoke(cli, ["-l", "-p", "myProject"], input="n\n")
+    runner.invoke(cmd_deploy.cli, ['-l', "-q", r'samples/simple_test'])
+    result = runner.invoke(cli, ["-l", "-p", "simple_test"], input="n\n")
     assert not result.exception
