@@ -2,6 +2,7 @@ import os
 
 from click.testing import CliRunner
 
+from roe.commands import cmd_deploy
 from roe.commands.cmd_verify import cli
 from roe.utilities.errors import *
 
@@ -18,7 +19,7 @@ def test_verify_nonlocal():
 def test_verify_base():
     """ Tests the bast case of verification works """
     runner = CliRunner()
-    result = runner.invoke(cli, ["-l", r"samples/myProject"])
+    result = runner.invoke(cli, ["-l", r"samples/simple_test"])
     assert not result.exception
     assert "Requirements.txt successfully found." in result.output
     assert "Failed model" not in result.output
@@ -35,3 +36,15 @@ def test_verify_empty_dir():
     assert not result.exception
     assert "needs to be configured" in result.output
     assert "No model folders with a config.yaml were found!" in result.output
+
+
+def test_verify_dupe():
+    """ Tests verify when there's a matching package already """
+    runner = CliRunner()
+    runner.invoke(cmd_deploy.cli, ['-l', "-q", r'samples/simple_test'])
+    result = runner.invoke(cli, ["-l", r"samples/simple_test"])
+    assert not result.exception
+    assert "Requirements.txt successfully found." in result.output
+    assert "Failed model" not in result.output
+    assert "Successfully verified model folders:\nheart_disease" in result.output
+    assert "non-model" not in result.output
